Crate bitcoinleveldb_memenv

Modules

in_memory_env

Structs

FileState
FileStateBlocks
FileStateRefs
InMemoryEnv

NoOpLogger

RandomAccessFileImpl

SequentialFileImpl

WritableFileImpl

Constants

FILE_STATE_BLOCK_SIZE

Functions

new_mem_env
| Returns a new environment that stores its data | in memory and delegates all non-file-storage | tasks to base_env. The caller must delete the | result when it is no longer needed. *base_env | must remain live while the result is in use.