Modules
Structs
- File
State - File
State Blocks - File
State Refs - InMemory
Env
- NoOp
Logger
- Random
Access File Impl
- Sequential
File Impl
- Writable
File Impl
Constants
Functions
- new_
mem_ env - | Returns a new environment that stores its data | in memory and delegates all non-file-storage | tasks to base_env. The caller must delete the | result when it is no longer needed. *base_env | must remain live while the result is in use.